@@ -3,6 +3,7 @@ from .base_node import BaseNode
 import numpy as np
 import pandas as pd
 
+
 class DataHolderNode(BaseNode):
     
     def __init__(self, graph_uid, graph_alias, node_uid, value=None, verbose=False):
@@ -19,7 +20,7 @@ class DataHolderNode(BaseNode):
     def has_value(self):
         return self.value is not None
 
-    def get_data_dim_as_str(self):
+    def get_persisted_data_dim_as_str(self):
         """Currently supports dimensionality from:
 
         numpy ndarray
@@ -32,7 +33,9 @@ class DataHolderNode(BaseNode):
             raise ValueError("There is no value!")
 
         if hasattr(self.value, "rdd"):
-            dim = ((self.value.count(), len(self.value.columns)))
+            row_cnt = self.get().persist().count()
+            col_cnt = len(self.get().columns)
+            dim = (row_cnt, col_cnt)
 
         elif isinstance(self.value, np.ndarray):
             dim = self.value.shape
@@ -48,4 +51,3 @@ class DataHolderNode(BaseNode):
     def __del__(self):
         if self.verbose:
             print('{} released!'.format(self.node_uid))
-
